# 🔻 giza (gizai)

📜 read the working paper: "A Related Set of Bash Expansions of Relevance to AI" - ([tex](./tex/giza.tex)), ([pdf](https://kamangir-public.s3.ca-central-1.amazonaws.com/giza-v1/giza.pdf)).

```bash
pip install gizai
```

---

🪄 [awesome bash cli](https://github.com/kamangir/awesome-bash-cli) (`abcli`) is an example implementation of `giza` ([svg](./assets/giza.svg)).

![image](./assets/giza.png)

---

> ℹ️ a push to this repo triggers a `giza build [publish]`.

[![PyPI version](https://img.shields.io/pypi/v/gizai.svg)](https://pypi.org/project/gizai/)
